LedgerBitmapBucketIter

Trait LedgerBitmapBucketIter 

pub trait LedgerBitmapBucketIter: Iterator<Item = Result<LedgerBitmapBucket, TypedStoreError>> {
    // Required method
    fn seek_bucket(&mut self, bucket_id: u64);
}
Iterator over ledger bitmap buckets that can skip directly to a bucket.

Required Methods

fn seek_bucket(&mut self, bucket_id: u64)

Reposition so the next row is the first bucket at or past bucket_id in the iterator’s direction. Implementations never move backward.

Implementors